==> bacula_2.4.4.orig.tar.gz: bacula-2.4.4/src/qt-console/joblog/joblog.h <==
#ifndef _JOBLOG_H_
#define _JOBLOG_H_
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of John Walker.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 *   Version $Id: joblog.h 4992 2007-06-07 14:46:43Z kerns $
 *
 *   Dirk Bartley, March 2007
 */

#include <QtGui>
#include "ui_joblog.h"
#include "console.h"

class JobLog : public Pages, public Ui::JobLogForm
{
   Q_OBJECT 

public:
   JobLog(QString &jobId, QTreeWidgetItem *parentTreeWidgetItem);

public slots:

private slots:

private:
   void display_text(const char *buf);
   void display_text(const QString buf);
   void populateText();
   void getFont();
   QTextCursor *m_cursor;
   QString m_jobId;
};

#endif /* _JOBLOG_H_ */

==> bacula_5.0.1.orig.tar.gz: bacula-5.0.1/src/qt-console/joblog/joblog.h <==
#ifndef _JOBLOG_H_
#define _JOBLOG_H_
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 *   Version $Id$
 *
 *   Dirk Bartley, March 2007
 */

#include <QtGui>
#include "ui_joblog.h"
#include "console.h"

class JobLog : public Pages, public Ui::JobLogForm
{
   Q_OBJECT 

public:
   JobLog(QString &jobId, QTreeWidgetItem *parentTreeWidgetItem);

public slots:

private slots:

private:
   void populateText();
   void getFont();
   QTextCursor *m_cursor;
   QString m_jobId;
};

#endif /* _JOBLOG_H_ */
